@@ -11,8 +11,13 @@ focusWidgets = []
 # This helps the Stage decide whether to show the clock widget or not while not Awake.
 # You get all sorts of artifacts trying to draw widgets over the x plugins
 PluginRunning = False
+# Our test for whether we should be showing the plugin:  If it's the user's preference
+# and if we're on ac power.
+def shouldShowPlugin():
+    from util import settings
+    import singletons
 
-# Set by command line args
+    return settings.should_show_plugin() and singletons.UPowerClient.plugged_in
 
 # This is different than the preference that turns off locking - that only prevents idle locking.  The
 # user can still lock explicitly.  The function checks for the existence of correct PAM files,
@@ -20,6 +25,8 @@ PluginRunning = False
 LockEnabled = True
 
 # Enables extra PAM/authentication/notification debugging
+# TODO: We do a *lot* of logging now, we should just use a debug() function that checks
+# for debug mode internally, instead of 'if status.Debug' everywhere.
 Debug = False
 
 # Forces the Stage to only cover a single monitor and launch a GtkInspector window.
@@ -28,3 +35,5 @@ InteractiveDebug = False
 # If the wallpaper aspect is 'spanned' we will only create one MonitorView and manage it slightly
 # differently.  This is an easy place to keep track of that.  This is set in singletons.py.
 Spanned = False
+
+screen = None
